==> vite-plugin-proxy-0.3.1.tgz: package/src/proxy.js <==
import proxy from 'http2-proxy'
import { pipe } from './http.js'
import createError from 'http-errors'
import zlib from 'zlib'

function decompress (stream, decompressor) {
  stream.pipe(decompressor)
  return decompressor
}

export function interceptData (req, res, { hostname, protocol, port, secure, headers: additionalHeaders }) {
  let buffer = ''
  let headers

  return new Promise((resolve, reject) => proxy.web(req, res, {
    hostname,
    protocol,
    port,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      Object.assign(headers, additionalHeaders)
      headers['accept-encoding'] = 'gzip, deflate'
    },
    onRes (req, res, proxyRes) {
      if (proxyRes.statusCode >= 400) {
        return reject(createError(proxyRes.statusCode, proxyRes.message))
      }

      headers = proxyRes.headers
      if (headers['content-encoding'] === 'gzip') {
        proxyRes = decompress(proxyRes, zlib.createGunzip())
      } else if (headers['content-encoding'] === 'deflate') {
        proxyRes = decompress(proxyRes, zlib.createInflate())
      }

      proxyRes
        .on('error', reject)
        .on('data', buf => (buffer += buf.toString()))
        .on('end', () => {
          if (headers['content-type'].startsWith('application/json')) {
            return resolve(JSON.parse(buffer))
          }
          resolve(buffer)
        })
    }
  }))
}

export async function all (req, res, { urls, headers: additionalHeaders, secure }) {
  if (req.aborted || res.readableEnded) return

  return Promise.all(urls.map(async ({ hostname, protocol, port }) => {
    return interceptData(req, res, {
      hostname,
      protocol,
      port,
      secure,
      headers: additionalHeaders
    })
  }))
}

export async function web (req, res, { hostname, protocol, port, headers: additionalHeaders, secure, onReq, onRes, path }) {
  if (req.aborted || res.readableEnded) return

  return proxy.web(req, res, {
    hostname,
    protocol,
    port,
    path,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      if (onReq) onReq.apply(this, arguments)
      Object.assign(headers, additionalHeaders)
    },
    onRes (req, res, proxyRes) {
      if (onRes) return onRes.apply(this, arguments)
      return pipe(proxyRes, res)
    }
  })
}

export async function ws (req, socket, head, { hostname, protocol, port, headers: additionalHeaders, secure, path }) {
  return proxy.ws(req, socket, head, {
    hostname,
    protocol,
    port,
    path,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      Object.assign(headers, additionalHeaders)
      Object.keys(headers).forEach(key => {
        if (headers[key] === undefined || headers[key] === null) delete headers[key]
      })
    }
  })
}

==> vite-plugin-proxy-0.4.2.tgz: package/src/proxy.js <==
import proxy from 'http2-proxy'
import { pipe } from './http.js'
import createError from 'http-errors'
import zlib from 'zlib'

function decompress (stream, decompressor) {
  stream.pipe(decompressor)
  return decompressor
}

export function interceptData (req, res, { hostname, protocol, port, secure = true, headers: additionalHeaders }) {
  let buffer = ''
  let headers

  return new Promise((resolve, reject) => proxy.web(req, res, {
    hostname,
    protocol,
    port,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      Object.assign(headers, additionalHeaders)
      headers['accept-encoding'] = 'gzip, deflate'
    },
    onRes (req, res, proxyRes) {
      if (proxyRes.statusCode >= 400) {
        return reject(createError(proxyRes.statusCode, proxyRes.message))
      }

      headers = proxyRes.headers
      if (headers['content-encoding'] === 'gzip') {
        proxyRes = decompress(proxyRes, zlib.createGunzip())
      } else if (headers['content-encoding'] === 'deflate') {
        proxyRes = decompress(proxyRes, zlib.createInflate())
      }

      proxyRes
        .on('error', reject)
        .on('data', buf => (buffer += buf.toString()))
        .on('end', () => {
          if (headers['content-type'].startsWith('application/json')) {
            return resolve(JSON.parse(buffer))
          }
          resolve(buffer)
        })
    }
  }))
}

export async function all (req, res, configs) {
  if (req.aborted || res.readableEnded) return

  return Promise.all(configs.map(async ({ url: { hostname, protocol, port }, headers, secure }) => {
    return interceptData(req, res, {
      hostname,
      protocol,
      port,
      secure,
      headers
    })
  }))
}

export async function web (req, res, { hostname, protocol, port, headers: additionalHeaders, secure = true, onReq, onRes, path }) {
  if (req.aborted || res.readableEnded) return

  return proxy.web(req, res, {
    hostname,
    protocol,
    port,
    path,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      if (onReq) onReq.apply(this, arguments)
      Object.assign(headers, additionalHeaders)
    },
    onRes (req, res, proxyRes) {
      if (onRes) return onRes.apply(this, arguments)
      return pipe(proxyRes, res)
    }
  })
}

export async function ws (req, socket, head, { hostname, protocol, port, headers: additionalHeaders, secure = true, path }) {
  return proxy.ws(req, socket, head, {
    hostname,
    protocol,
    port,
    path,
    rejectUnauthorized: secure,
    onReq (req, { headers }) {
      Object.assign(headers, additionalHeaders)
      Object.keys(headers).forEach(key => {
        if (headers[key] === undefined || headers[key] === null) delete headers[key]
      })
    }
  })
}
